@echo off
setlocal enableextensions enabledelayedexpansion


:SETUP
	echo.%*|find /i "/?">nul:
	if %errorlevel% equ 0 goto :HELP
	echo.%*|find /i "/h">nul:
	if %errorlevel% equ 0 goto :HELP
	echo.%*|find /i "/help">nul:
	if %errorlevel% equ 0 goto :HELP
	
	set bat_date=%date:~-10%
	if "%~1" neq "" (
		set bat_date=%~1
	)

	echo.
	echo.!bat_date!|find /i "/" 1>2>nul:
	if !errorlevel! NEQ 0 (goto :DONE)

	for /f "delims=/ tokens=1-3" %%a in ("!bat_date!") do (
		set bat_mo=0%%a
		set bat_mo=!bat_mo:~-2!
		set bat_da=0%%b
		set bat_da=!bat_da:~-2!
		set bat_year=20%%c
		set bat_year=!bat_year:~-4!
	)

	call :date2jdate bat_jd !bat_year! !bat_mo! !bat_da!
	set /a bat_jd+=1


goto :MAIN

:MAIN
	set /a bat_jd2=!bat_jd!-2
	for /L %%p in (!bat_jd2!,1,!bat_jd!) do (
		call :jdate2date %%p bat_year bat_mo bat_da

		set bat_date=!bat_year!_!bat_mo!_!bat_da!
		set bat_datemin=!bat_year!!bat_mo!!bat_da!

		echo.
		echo --------!bat_datemin!--------
		rem echo for /f "usebackq tokens=*" %%a in ^(`dir "ArchivedFiles\ff???_!bat_datemin!_*.bin" /s/b /a-d 2^>nul`^) do ...
		set /a bat_count=0

		for /f "usebackq tokens=*" %%a in (`dir "ArchivedFiles\ff???_!bat_datemin!_*.bin" /s/b /a-d 2^>nul`) do (
			set /a bat_count+=1
			set bat_lastfilename=%%a
			if !bat_count! equ 1 (
				set bat_firstfilename=%%a
			)

			rem Trim trailing backslash using ::
			set bat_temp=%%~dpa::
			set bat_savepath=!bat_temp:\::=!
		)&	rem end for /f....

		if !bat_count! neq 0 (
			set bat_savefirst=!bat_firstfilename!
			set bat_savelast=!bat_lastfilename!
			echo Path:       "!bat_savepath!"
			echo First File: "!bat_firstfilename!"
			echo Last File:  "!bat_lastfilename!"
			echo Count:      !bat_count!
		) else (
			echo Target dir not found: ".\ArchivedFiles\!bat_date!_*"  "ArchivedFiles\ff???_!bat_datemin!_*.bin"
		)
	)& rem end for /L...
	title Last file="!bat_savelast!"
exit /b



:date2jdate JD YYYY MM DD -- converts a gregorian calender date to julian day format
	setlocal
	rem                        -- JD   [out] - julian days
	rem                        -- YYYY [in]  - gregorian year, i.e. 2006
	rem                        -- MM   [in]  - gregorian month, i.e. 12 for december
	rem                        -- DD   [in]  - gregorian day, i.e. 31
	rem :$reference http://aa.usno.navy.mil/faq/docs/JD_Formula.html
	rem :$created 20060101 :$changed 20080219 :$categories DateAndTime
	rem :$source http://www.dostips.com
	set "yy=%~2"&set "mm=%~3"&set "dd=%~4"
	set /a "yy=10000%yy% %%10000,mm=100%mm% %% 100,dd=100%dd% %% 100"
	if %yy% LSS 100 set /a yy+=2000 &rem Adds 2000 to two digit years
	set /a JD=dd-32075+1461*(yy+4800+(mm-14)/12)/4+367*(mm-2-(mm-14)/12*12)/12-3*((yy+4900+(mm-14)/12)/100)/4
	ENDLOCAL & IF "%~1" NEQ "" (SET %~1=%JD%) ELSE (echo.%JD%)
EXIT /b 0

:jdate2date JD YYYY MM DD -- converts julian days to gregorian date format
	rem                     -- JD   [in]  - julian days
	rem                     -- YYYY [out] - gregorian year, i.e. 2006
	rem                     -- MM   [out] - gregorian month, i.e. 12 for december
	rem                      -- DD   [out] - gregorian day, i.e. 31
	rem :$reference http://aa.usno.navy.mil/faq/docs/JD_Formula.html
	rem :$created 20060101 :$changed 20080219 :$categories DateAndTime
	rem :$source http://www.dostips.com
	SETLOCAL ENABLEDELAYEDEXPANSION
	set /a L= %~1+68569,     N= 4*L/146097, L= L-(146097*N+3)/4, I= 4000*(L+1)/1461001
	set /a L= L-1461*I/4+31, J= 80*L/2447,  K= L-2447*J/80,      L= J/11
	set /a J= J+2-12*L,      I= 100*(N-49)+I+L
	set /a YYYY= I,  MM=100+J,  DD=100+K
	set MM=%MM:~-2%
	set DD=%DD:~-2%
	( ENDLOCAL & REM RETURN VALUES
	    IF "%~2" NEQ "" (SET %~2=%YYYY%) ELSE echo.%YYYY%
	    IF "%~3" NEQ "" (SET %~3=%MM%) ELSE echo.%MM%
	    IF "%~4" NEQ "" (SET %~4=%DD%) ELSE echo.%DD%
	)
EXIT /b 0


:HELP
echo.
echo  %~nx0  Batch Script
echo.
echo  Usage: %~nx0 [date]
echo.
echo  Lists whether files exist in the ArchivedFiles subdir.  If the date 
echo  specified, it will start with the specified date.  If no date is specified, 
echo  the current date is used as the starting date.  If the optional date is 
echo  specified, the date specified is used as the starting date.  Once the starting date
echo  is determined, the script scans three directories:
echo.
echo      1) the directory correlating with the date 1 day before the starting date
echo      2) the directory correlating with the current date
echo      3) the directory correlating with the date 1 day after the starting date
echo.
echo   Example 1:
echo    %~nx0
echo 	--------20110816--------
echo 	Target dir not found: ".\ArchivedFiles\2011_08_16_*"  "ArchivedFiles\ff???_20110816_*.bin"
echo.
echo 	--------20110817--------
echo 	Path:       "F:\CAMS\ArchivedFiles\2011_08_17_05_00_35"
echo 	First File: "F:\CAMS\ArchivedFiles\2011_08_17_05_00_35\FF213_20110817_050035_466_0000256.bin"
echo 	Last File:  "F:\CAMS\ArchivedFiles\2011_08_17_05_00_35\FF213_20110817_123121_066_0810496.bin"
echo 	Count:      291
echo.
echo 	--------20110818--------
echo 	Target dir not found: ".\ArchivedFiles\2011_08_18_*"  "ArchivedFiles\ff???_20110818_*.bin"
echo.
echo.
echo   Example 2:
echo    %~nx0 08/21/2011
echo 	--------20110821--------
echo 	Path:       "F:\CAMS\ArchivedFiles\2011_08_21_11_04_20"
echo 	First File: "F:\CAMS\ArchivedFiles\2011_08_21_11_04_20\FF213_20110821_110437_685_0000768.bin"
echo 	Last File:  "F:\CAMS\ArchivedFiles\2011_08_21_11_04_20\FF213_20110821_114747_888_0078336.bin"
echo 	Count:      24
echo.
echo 	--------20110822--------
echo 	Path:       "F:\CAMS\ArchivedFiles\2011_08_22_06_58_10"
echo 	First File: "F:\CAMS\ArchivedFiles\2011_08_22_06_58_10\FF213_20110822_032541_715_0045824.bin"
echo 	Last File:  "F:\CAMS\ArchivedFiles\2011_08_22_06_58_10\FF213_20110822_123843_427_0989184.bin"
echo 	Count:      537
echo.
echo 	--------20110823--------
echo 	Target dir not found: ".\ArchivedFiles\2011_08_23_*"  "ArchivedFiles\ff???_20110823_*.bin"
echo.



goto :DONE


:DONE
